==> hcloud-1.51.0.tar.xz: hcloud-1.51.0/docs/reference/manual/hcloud_server.md <==
## hcloud server

Manage Servers

### Options

```
  -h, --help   help for server
```

### Options inherited from parent commands

```
      --config string            Config file path (default "~/.config/hcloud/cli.toml")
      --context string           Currently active context
      --debug                    Enable debug output
      --debug-file string        File to write debug output to
      --endpoint string          Hetzner Cloud API endpoint (default "https://api.hetzner.cloud/v1")
      --poll-interval duration   Interval at which to poll information, for example action progress (default 500ms)
      --quiet                    If true, only print error messages
```

### SEE ALSO

* [hcloud](hcloud.md)	 - Hetzner Cloud CLI
* [hcloud server add-label](hcloud_server_add-label.md)	 - Add a label to a Server
* [hcloud server add-to-placement-group](hcloud_server_add-to-placement-group.md)	 - Add a Server to a Placement Group
* [hcloud server attach-iso](hcloud_server_attach-iso.md)	 - Attach an ISO to a server
* [hcloud server attach-to-network](hcloud_server_attach-to-network.md)	 - Attach a Server to a Network
* [hcloud server change-alias-ips](hcloud_server_change-alias-ips.md)	 - Change a server's alias IPs in a Network
* [hcloud server change-type](hcloud_server_change-type.md)	 - Change type of a server
* [hcloud server create](hcloud_server_create.md)	 - Create a Server
* [hcloud server create-image](hcloud_server_create-image.md)	 - Create an Image from a Server
* [hcloud server delete](hcloud_server_delete.md)	 - Delete a server
* [hcloud server describe](hcloud_server_describe.md)	 - Describe a Server
* [hcloud server detach-from-network](hcloud_server_detach-from-network.md)	 - Detach a Server from a Network
* [hcloud server detach-iso](hcloud_server_detach-iso.md)	 - Detach an ISO from a Server
* [hcloud server disable-backup](hcloud_server_disable-backup.md)	 - Disable backup for a server
* [hcloud server disable-protection](hcloud_server_disable-protection.md)	 - Disable resource protection for a server
* [hcloud server disable-rescue](hcloud_server_disable-rescue.md)	 - Disable rescue for a server
* [hcloud server enable-backup](hcloud_server_enable-backup.md)	 - Enable backup for a server
* [hcloud server enable-protection](hcloud_server_enable-protection.md)	 - Enable resource protection for a server
* [hcloud server enable-rescue](hcloud_server_enable-rescue.md)	 - Enable rescue for a server
* [hcloud server ip](hcloud_server_ip.md)	 - Print a server's IP address
* [hcloud server list](hcloud_server_list.md)	 - List Servers
* [hcloud server metrics](hcloud_server_metrics.md)	 - [ALPHA] Metrics from a Server
* [hcloud server poweroff](hcloud_server_poweroff.md)	 - Poweroff a Server
* [hcloud server poweron](hcloud_server_poweron.md)	 - Poweron a server
* [hcloud server reboot](hcloud_server_reboot.md)	 - Reboot a server
* [hcloud server rebuild](hcloud_server_rebuild.md)	 - Rebuild a server
* [hcloud server remove-from-placement-group](hcloud_server_remove-from-placement-group.md)	 - Removes a Server from a Placement Group
* [hcloud server remove-label](hcloud_server_remove-label.md)	 - Remove a label from a Server
* [hcloud server request-console](hcloud_server_request-console.md)	 - Request a WebSocket VNC console for a Server
* [hcloud server reset](hcloud_server_reset.md)	 - Reset a Server
* [hcloud server reset-password](hcloud_server_reset-password.md)	 - Reset the root password of a Server
* [hcloud server set-rdns](hcloud_server_set-rdns.md)	 - Change reverse DNS of a Server
* [hcloud server shutdown](hcloud_server_shutdown.md)	 - Shutdown a server
* [hcloud server ssh](hcloud_server_ssh.md)	 - Spawn an SSH connection for the Server
* [hcloud server update](hcloud_server_update.md)	 - Update a Server

==> hcloud-1.58.0.tar.xz: hcloud-1.58.0/docs/reference/manual/hcloud_server.md <==
## hcloud server

Manage Servers

### Options

```
  -h, --help   help for server
```

### Options inherited from parent commands

```
      --config string              Config file path (default "~/.config/hcloud/cli.toml")
      --context string             Currently active context
      --debug                      Enable debug output
      --debug-file string          File to write debug output to
      --endpoint string            Hetzner Cloud API endpoint (default "https://api.hetzner.cloud/v1")
      --hetzner-endpoint string    Hetzner API endpoint (default "https://api.hetzner.com/v1")
      --no-experimental-warnings   If true, experimental warnings are not shown
      --poll-interval duration     Interval at which to poll information, for example action progress (default 500ms)
      --quiet                      If true, only print error messages
```

### SEE ALSO

* [hcloud](hcloud.md)	 - Hetzner Cloud CLI
* [hcloud server add-label](hcloud_server_add-label.md)	 - Add a label to a Server
* [hcloud server add-to-placement-group](hcloud_server_add-to-placement-group.md)	 - Add a Server to a Placement Group
* [hcloud server attach-iso](hcloud_server_attach-iso.md)	 - Attach an ISO to a server
* [hcloud server attach-to-network](hcloud_server_attach-to-network.md)	 - Attach a Server to a Network
* [hcloud server change-alias-ips](hcloud_server_change-alias-ips.md)	 - Change a server's alias IPs in a Network
* [hcloud server change-type](hcloud_server_change-type.md)	 - Change type of a server
* [hcloud server create](hcloud_server_create.md)	 - Create a Server
* [hcloud server create-image](hcloud_server_create-image.md)	 - Create an Image from a Server
* [hcloud server delete](hcloud_server_delete.md)	 - Delete a server
* [hcloud server describe](hcloud_server_describe.md)	 - Describe a Server
* [hcloud server detach-from-network](hcloud_server_detach-from-network.md)	 - Detach a Server from a Network
* [hcloud server detach-iso](hcloud_server_detach-iso.md)	 - Detach an ISO from a Server
* [hcloud server disable-backup](hcloud_server_disable-backup.md)	 - Disable backup for a server
* [hcloud server disable-protection](hcloud_server_disable-protection.md)	 - Disable resource protection for a Server
* [hcloud server disable-rescue](hcloud_server_disable-rescue.md)	 - Disable rescue for a server
* [hcloud server enable-backup](hcloud_server_enable-backup.md)	 - Enable backup for a server
* [hcloud server enable-protection](hcloud_server_enable-protection.md)	 - Enable resource protection for a Server
* [hcloud server enable-rescue](hcloud_server_enable-rescue.md)	 - Enable rescue for a server
* [hcloud server ip](hcloud_server_ip.md)	 - Print a server's IP address
* [hcloud server list](hcloud_server_list.md)	 - List Servers
* [hcloud server metrics](hcloud_server_metrics.md)	 - [ALPHA] Metrics from a Server
* [hcloud server poweroff](hcloud_server_poweroff.md)	 - Poweroff a Server
* [hcloud server poweron](hcloud_server_poweron.md)	 - Poweron a server
* [hcloud server reboot](hcloud_server_reboot.md)	 - Reboot a server
* [hcloud server rebuild](hcloud_server_rebuild.md)	 - Rebuild a server
* [hcloud server remove-from-placement-group](hcloud_server_remove-from-placement-group.md)	 - Removes a Server from a Placement Group
* [hcloud server remove-label](hcloud_server_remove-label.md)	 - Remove a label from a Server
* [hcloud server request-console](hcloud_server_request-console.md)	 - Request a WebSocket VNC console for a Server
* [hcloud server reset](hcloud_server_reset.md)	 - Reset a Server
* [hcloud server reset-password](hcloud_server_reset-password.md)	 - Reset the root password of a Server
* [hcloud server set-rdns](hcloud_server_set-rdns.md)	 - Change reverse DNS of a Server
* [hcloud server shutdown](hcloud_server_shutdown.md)	 - Shutdown a server
* [hcloud server ssh](hcloud_server_ssh.md)	 - Spawn an SSH connection for the Server
* [hcloud server update](hcloud_server_update.md)	 - Update a Server
